@@ -1,6 +1,5 @@
-from typing import Type
+from typing import Any, Type
 from flask_sqlalchemy import SQLAlchemy
-from sqlalchemy.sql.sqltypes import TypeEngine
 from .model import Model
 
 
@@ -9,6 +8,7 @@ def Column(
     primary_key: bool = None,
     nullable: bool = None,
     unique: bool = None,
+    default: Any = None
 ): pass
 
 
